package hdl

import (
	"applet/app/admin/lib/validate"
	"applet/app/admin/md"
	"applet/app/admin/svc"
	svc2 "applet/app/admin/svc/enterprise_manage"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/e"
	"applet/app/enum"
	"applet/app/utils"
	"fmt"
	"github.com/gin-gonic/gin"
	"time"
)

func CentralKitchenForSchoolUserUpdate(c *gin.Context) {
	var req md.CentralKitchenForSchoolUserUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.CentralKitchenForSchoolUserUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolUserDelete(c *gin.Context) {
	var req md.CentralKitchenForSchoolUserDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.CentralKitchenForSchoolUserDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolStudentList(c *gin.Context) {
	var req md.CentralKitchenForSchoolStudentListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolStudentList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"admission_list": []map[string]string{
			{
				"name":  "按班级",
				"value": "admission_type_by_class",
			},
			{
				"name":  "按年级",
				"value": "admission_type_by_grade",
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolTeacherList(c *gin.Context) {
	var req md.CentralKitchenForSchoolTeacherListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolTeacherList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func CentralKitchenForSchoolTeacherUpdate(c *gin.Context) {
	var req md.CentralKitchenForSchoolTeacherUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	userIdentity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if userIdentity == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	userIdentity.IdNo = req.IdNo
	userIdentity.Name = req.Name
	_, err = userIdentityDb.UserIdentityUpdate(req.UserIdentityId, userIdentity, "id_no", "name")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolStudentUpdate(c *gin.Context) {
	var req md.CentralKitchenForSchoolStudentUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc2.CentralKitchenForSchoolStudentUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolStudentAdmission(c *gin.Context) {
	var req md.CentralKitchenForSchoolStudentAdmissionReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.CentralKitchenForSchoolStudentAdmission(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolBatchStudentAdmission(c *gin.Context) {
	Kind := c.DefaultQuery("kind", "1")
	switch Kind {
	case "1":
		//按学校
		var req md.CentralKitchenForSchoolStudentAdmissionBySchool
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		err = svc2.CentralKitchenForSchoolStudentAdmissionBySchool(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	case "2":
		//按年级
		var req md.CentralKitchenForSchoolStudentAdmissionByGrade
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		err = svc2.CentralKitchenForSchoolStudentAdmissionByGrade(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	case "3":
		//按班级
		var req md.CentralKitchenForSchoolStudentAdmissionByClass
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		err = svc2.CentralKitchenForSchoolStudentAdmissionByClass(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolStudentDelete(c *gin.Context) {
	var req md.CentralKitchenForSchoolStudentDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.CentralKitchenForSchoolStudentDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolTeacherDelete(c *gin.Context) {
	var req md.CentralKitchenForSchoolTeacherDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("id", req.UserIdentityIds).Delete(model.UserIdentity{})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func GetCentralKitchenForSchoolWithSpecByTeacher(c *gin.Context) {
	enterpriseId := utils.StrToInt(c.DefaultQuery("enterprise_id", "0"))
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(enterpriseId)
	data, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"data": data,
	}, nil)
	return
}

func SetCentralKitchenForSchoolWithSpecByTeacher(c *gin.Context) {
	var req md.SetCentralKitchenForSchoolWithSpecReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(req.EnterpriseId)

	spec, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	_, err = centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecDelete()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	now := time.Now()
	if spec != nil {
		insertConfirm, err1 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecInsert(&model.CentralKitchenForSchoolWithSpec{
			IsOpenBreakfast:              spec.IsOpenBreakfast,
			IsOpenLunch:                  spec.IsOpenLunch,
			IsOpenDinner:                 spec.IsOpenDinner,
			EnterpriseId:                 req.EnterpriseId,
			BreakfastUnitPrice:           req.BreakfastUnitPrice,
			LunchUnitPrice:               req.LunchUnitPrice,
			DinnerUnitPrice:              req.DinnerUnitPrice,
			BreakfastUnitPriceForTeacher: req.BreakfastUnitPriceForTeacher,
			LunchUnitPriceForTeacher:     req.LunchUnitPriceForTeacher,
			DinnerUnitPriceForTeacher:    req.DinnerUnitPriceForTeacher,
			CreateAt:                     now.Format("2006-01-02 15:04:05"),
			UpdateAt:                     now.Format("2006-01-02 15:04:05"),
		})
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		if insertConfirm <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "新增数据失败")
			return
		}
	} else {
		insertConfirm, err1 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecInsert(&model.CentralKitchenForSchoolWithSpec{
			EnterpriseId:                 req.EnterpriseId,
			BreakfastUnitPrice:           req.BreakfastUnitPrice,
			LunchUnitPrice:               req.LunchUnitPrice,
			DinnerUnitPrice:              req.DinnerUnitPrice,
			BreakfastUnitPriceForTeacher: req.BreakfastUnitPriceForTeacher,
			LunchUnitPriceForTeacher:     req.LunchUnitPriceForTeacher,
			DinnerUnitPriceForTeacher:    req.DinnerUnitPriceForTeacher,
			CreateAt:                     now.Format("2006-01-02 15:04:05"),
			UpdateAt:                     now.Format("2006-01-02 15:04:05"),
		})
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		if insertConfirm <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "新增数据失败")
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func SetCentralKitchenForSchoolWithSpecByPeriod(c *gin.Context) {
	var req md.SetCentralKitchenForSchoolWithSpecByPeriodReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	for _, v := range req.List {
		periodDb := db.PeriodDb{}
		periodDb.Set(req.EnterpriseId)
		period, err1 := periodDb.GetPeriod(v.PeriodId)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		period.BreakfastUnitPrice = v.BreakfastUnitPrice
		period.LunchUnitPrice = v.LunchUnitPrice
		period.DinnerUnitPrice = v.DinnerUnitPrice
		_, err2 := periodDb.PeriodUpdate(period, "breakfast_unit_price", "lunch_unit_price", "dinner_unit_price")
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func ListCentralKitchenForSchoolPackage(c *gin.Context) {
	var req md.ListCentralKitchenForSchoolPackageReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	centralKitchenForSchoolPackageDb := db.CentralKitchenForSchoolPackageDb{}
	centralKitchenForSchoolPackageDb.Set()
	list, total, err := centralKitchenForSchoolPackageDb.CentralKitchenForSchoolPackageList(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  list,
		"total": total,
		"state_list": []map[string]interface{}{
			{
				"name":  "可用",
				"value": 1,
			},
			{
				"name":  "不可用",
				"value": 2,
			},
		},
	}, nil)
	return
}

func DetailCentralKitchenForSchoolPackage(c *gin.Context) {
	packageId := utils.StrToInt(c.DefaultQuery("package_id", ""))
	centralKitchenForSchoolPackageDb := db.CentralKitchenForSchoolPackageDb{}
	centralKitchenForSchoolPackageDb.Set()
	centralKitchenForSchoolPackage, err := centralKitchenForSchoolPackageDb.GetCentralKitchenForSchoolPackage(packageId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if centralKitchenForSchoolPackage == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	centralKitchenForSchoolPackageWithDayDb := db.CentralKitchenForSchoolPackageWithDayDb{}
	centralKitchenForSchoolPackageWithDayDb.Set(packageId)
	centralKitchenForSchoolPackageWithDay, err := centralKitchenForSchoolPackageWithDayDb.FindCentralKitchenForSchoolPackageWithDay()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	var resp = md.SaveCentralKitchenForSchoolPackageReq{
		PackageId:    centralKitchenForSchoolPackage.Id,
		EnterpriseId: centralKitchenForSchoolPackage.EnterpriseId,
		Year:         centralKitchenForSchoolPackage.Year,
		Month:        centralKitchenForSchoolPackage.Month,
		StartDate:    centralKitchenForSchoolPackage.StartDate,
		EndDate:      centralKitchenForSchoolPackage.EndDate,
		DateList:     nil,
	}
	for _, v := range *centralKitchenForSchoolPackageWithDay {
		resp.DateList = append(resp.DateList, struct {
			Date            string `json:"date"`
			IsOpenBreakfast int32  `json:"is_open_breakfast"`
			IsOpenLunch     int32  `json:"is_open_lunch"`
			IsOpenDinner    int32  `json:"is_open_dinner"`
			IsOpenReplenish int32  `json:"is_open_replenish"`
		}{Date: v.Date, IsOpenBreakfast: int32(v.IsOpenBreakfast), IsOpenLunch: int32(v.IsOpenLunch), IsOpenDinner: int32(v.IsOpenDinner), IsOpenReplenish: int32(v.IsOpenReplenish)})
	}
	e.OutSuc(c, resp, nil)
	return
}

func SaveCentralKitchenForSchoolPackage(c *gin.Context) {
	var req md.SaveCentralKitchenForSchoolPackageReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	//判断是新增 / 编辑
	if req.PackageId > 0 {
		err = svc.UpdateCentralKitchenForSchoolPackage(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
	} else {
		err = svc.AddCentralKitchenForSchoolPackage(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
	}
	e.OutSuc(c, "success", nil)
	return
}

func DeleteCentralKitchenForSchoolPackage(c *gin.Context) {
	packageId := c.Param("id")
	err := svc.DeleteCentralKitchenForSchoolPackage(utils.StrToInt(packageId))
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SetBasicCentralKitchenForSchool(c *gin.Context) {
	var req md.SetBasicCentralKitchenForSchoolReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	now := time.Now()

	//1、更新 central_kitchen_for_school_set
	centralKitchenForSchoolSetDb := db.CentralKitchenForSchoolSetDb{}
	centralKitchenForSchoolSetDb.Set(req.EnterpriseId)
	set, err := centralKitchenForSchoolSetDb.GetCentralKitchenForSchoolSet()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if set != nil {
		set.IsOpenTeacherReportMeal = req.IsOpenTeacherReportMeal
		set.IsOpenReportMealForDay = req.IsOpenReportMealForDay
		set.IsOpenReportMealForMonth = req.IsOpenReportMealForMonth
		set.IsOpenReportMealForSemester = req.IsOpenReportMealForSemester
		set.IsOpenTeacherReportMealForDay = req.IsOpenTeacherReportMealForDay
		set.IsOpenTeacherReportMealForMonth = req.IsOpenTeacherReportMealForMonth
		set.IsOpenTeacherReportMealForSemester = req.IsOpenTeacherReportMealForSemester
		set.UpdateAt = now.Format("2006-01-02 15:04:05")
		_, err2 := centralKitchenForSchoolSetDb.CentralKitchenForSchoolSetUpdate(set.Id, set,
			"is_open_report_meal_for_day", "is_open_report_meal_for_month", "is_open_report_meal_for_semester",
			"is_open_teacher_report_meal", "is_open_teacher_report_meal_for_day", "is_open_teacher_report_meal_for_month", "is_open_teacher_report_meal_for_semester", "update_at")
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	} else {
		_, err2 := centralKitchenForSchoolSetDb.CentralKitchenForSchoolSetInsert(&model.CentralKitchenForSchoolSet{
			EnterpriseId:                       req.EnterpriseId,
			IsOpenTeacherReportMeal:            req.IsOpenTeacherReportMeal,
			IsOpenReportMealForDay:             req.IsOpenReportMealForDay,
			IsOpenReportMealForMonth:           req.IsOpenReportMealForMonth,
			IsOpenReportMealForSemester:        req.IsOpenReportMealForSemester,
			IsOpenTeacherReportMealForDay:      req.IsOpenTeacherReportMealForDay,
			IsOpenTeacherReportMealForMonth:    req.IsOpenTeacherReportMealForMonth,
			IsOpenTeacherReportMealForSemester: req.IsOpenTeacherReportMealForSemester,
			CreateAt:                           now.Format("2006-01-02 15:04:05"),
			UpdateAt:                           now.Format("2006-01-02 15:04:05"),
		})
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	//2、更新 central_kitchen_for_school_with_spec
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(req.EnterpriseId)
	spec, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if spec != nil {
		spec.IsOpenBreakfast = req.IsOpenBreakfast
		spec.IsOpenLunch = req.IsOpenLunch
		spec.IsOpenDinner = req.IsOpenDinner
		spec.UpdateAt = now.Format("2006-01-02 15:04:05")
		_, err2 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecUpdate(spec.Id, spec, "is_open_breakfast", "is_open_lunch", "is_open_dinner", "update_at")
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	} else {
		_, err2 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecInsert(&model.CentralKitchenForSchoolWithSpec{
			EnterpriseId:    req.EnterpriseId,
			IsOpenBreakfast: req.IsOpenBreakfast,
			IsOpenLunch:     req.IsOpenLunch,
			IsOpenDinner:    req.IsOpenDinner,
			CreateAt:        now.Format("2006-01-02 15:04:05"),
			UpdateAt:        now.Format("2006-01-02 15:04:05"),
		})
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	//3、更新 `enterprise`
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	enterprise.Name = req.Name
	enterprise.State = req.State
	enterprise.UpdateAt = now.Format("2006-01-02 15:04:05")
	_, err = enterpriseDb.EnterpriseUpdate(enterprise, "name", "state", "update_at")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func GetBasicCentralKitchenForSchool(c *gin.Context) {
	enterpriseId := utils.StrToInt(c.DefaultQuery("enterprise_id", "0"))

	//1、获取 central_kitchen_for_school_set
	centralKitchenForSchoolSetDb := db.CentralKitchenForSchoolSetDb{}
	centralKitchenForSchoolSetDb.Set(enterpriseId)
	set, err := centralKitchenForSchoolSetDb.GetCentralKitchenForSchoolSet()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if set == nil {
		set = &model.CentralKitchenForSchoolSet{
			EnterpriseId:                       enterpriseId,
			IsOpenTeacherReportMeal:            1,
			IsOpenReportMealForDay:             1,
			IsOpenReportMealForMonth:           1,
			IsOpenReportMealForSemester:        1,
			IsOpenTeacherReportMealForDay:      1,
			IsOpenTeacherReportMealForMonth:    1,
			IsOpenTeacherReportMealForSemester: 1,
			CreateAt:                           time.Now().Format("2006-01-02 15:04:05"),
			UpdateAt:                           time.Now().Format("2006-01-02 15:04:05"),
		}
		_, err2 := centralKitchenForSchoolSetDb.CentralKitchenForSchoolSetInsert(set)
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	//2、获取 central_kitchen_for_school_with_spec
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(enterpriseId)
	spec, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if spec == nil {
		spec = &model.CentralKitchenForSchoolWithSpec{
			EnterpriseId:                 enterpriseId,
			IsOpenBreakfast:              0,
			IsOpenLunch:                  0,
			IsOpenDinner:                 0,
			BreakfastUnitPrice:           "0",
			LunchUnitPrice:               "0",
			DinnerUnitPrice:              "0",
			BreakfastUnitPriceForTeacher: "0",
			LunchUnitPriceForTeacher:     "0",
			DinnerUnitPriceForTeacher:    "0",
			CreateAt:                     time.Now().Format("2006-01-02 15:04:05"),
			UpdateAt:                     time.Now().Format("2006-01-02 15:04:05"),
		}
		_, err2 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecInsert(spec)
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	//3、更新 `enterprise`
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(enterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"central_kitchen_for_school_set":       set,
		"central_kitchen_for_school_with_spec": spec,
		"enterprise":                           enterprise,
	}, nil)
	return
}

func CentralKitchenForSchoolOrdList(c *gin.Context) {
	var req md.CentralKitchenForSchoolOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//enterpriseDb := db.EnterpriseDb{}
	//enterpriseDb.Set()
	//enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	//if err != nil {
	//	e.OutErr(c, e.ERR_DB_ORM, err.Error())
	//	return
	//}
	//if enterprise == nil {
	//	e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
	//	return
	//}

	resp, total, err := svc2.CentralKitchenForSchoolOrdList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"kind_list": []map[string]string{
			{
				"name":  "按学期购买",
				"value": "1",
			},
			{
				"name":  "按月购买",
				"value": "2",
			},
			{
				"name":  "按天购买",
				"value": "3",
			},
			{
				"name":  "补餐",
				"value": "4",
			},
		},
		"state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdState.String(enum.CentralKitchenForSchoolPackageOrdStateForWait),
				"value": enum.CentralKitchenForSchoolPackageOrdStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdState.String(enum.CentralKitchenForSchoolPackageOrdStateForSuccess),
				"value": enum.CentralKitchenForSchoolPackageOrdStateForSuccess,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdState.String(enum.CentralKitchenForSchoolPackageOrdStateForFail),
				"value": enum.CentralKitchenForSchoolPackageOrdStateForFail,
			},
		},
		"ord_state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForWait),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForSuccess),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForSuccess,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunding),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunding,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForPartRefunded),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForPartRefunded,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunded),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunded,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForComplete),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForComplete,
			},
		},
		"user_identity_kind_list": []map[string]interface{}{
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForCentralKitchenForStudent),
				"value": enum.UserIdentityForCentralKitchenForStudent,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForCentralKitchenForTeacher),
				"value": enum.UserIdentityForCentralKitchenForTeacher,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForCentralKitchenForWorker),
				"value": enum.UserIdentityForCentralKitchenForWorker,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForSelfSupportForStudent),
				"value": enum.UserIdentityForSelfSupportForStudent,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForSelfSupportForTeacher),
				"value": enum.UserIdentityForSelfSupportForTeacher,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForSelfSupportForWorker),
				"value": enum.UserIdentityForSelfSupportForWorker,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolReserveList(c *gin.Context) {
	var req md.CentralKitchenForSchoolReserveListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolReserveList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForBreakfast),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForLunch),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForLunch,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForDinner),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForDinner,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolReserveUpdateStudent(c *gin.Context) {
	if c.Request.Method != "GET" {
		var req md.CentralKitchenForSchoolReserveUpdateStudentReq
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		//1、查询对应的 user_identity
		userIdentityDb := db.UserIdentityDb{}
		userIdentityDb.Set(req.Uid)
		identity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}

		//1、修改 central_kitchen_for_school_package_ord_for_reserve
		centralKitchenForSchoolPackageOrdForReserveDb := db.CentralKitchenForSchoolPackageOrdForReserve{}
		centralKitchenForSchoolPackageOrdForReserveDb.Set("")
		centralKitchenForSchoolPackageOrdForReserve, err := centralKitchenForSchoolPackageOrdForReserveDb.GetCentralKitchenForSchoolPackageOrdForReserveById(req.Id)
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		if centralKitchenForSchoolPackageOrdForReserve == nil {
			e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
			return
		}
		centralKitchenForSchoolPackageOrdForReserve.UserIdentityId = req.UserIdentityId
		centralKitchenForSchoolPackageOrdForReserve.UserIdentityName = identity.Name
		centralKitchenForSchoolPackageOrdForReserve.EnterpriseId = identity.EnterpriseId
		centralKitchenForSchoolPackageOrdForReserve.UpdateAt = time.Now().Format("2006-01-02 15:04:05")
		updateAffected, err := centralKitchenForSchoolPackageOrdForReserveDb.CentralKitchenForSchoolPackageOrdForReserveUpdate(centralKitchenForSchoolPackageOrdForReserve, "enterprise_id", "user_identity_name", "user_identity_id", "update_at")
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		if updateAffected <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "更新预定记录失败")
			return
		}

		//2、修改 central_kitchen_for_school_user_with_day
		sql := "update central_kitchen_for_school_user_with_day set identity_id = %d where identity_id = %d and kind = %d and date >= '%s' and date <= '%s'"
		sql = fmt.Sprintf(sql, req.UserIdentityId, req.OriginalUserIdentityId, centralKitchenForSchoolPackageOrdForReserve.Kind, centralKitchenForSchoolPackageOrdForReserve.MealTimeStart, centralKitchenForSchoolPackageOrdForReserve.MealTimeEnd)
		fmt.Println("sql >>>>>", sql)
		_, err = db.ExecuteOriginalSql(db.Db, sql)
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		e.OutSuc(c, "success", nil)
		return
	}

	//查询出当前用户下所有身份
	uid := c.DefaultQuery("uid", "")
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(utils.StrToInt(uid))
	identity, err := userIdentityDb.FindUserIdentityByKind(enum.UserIdentityForCentralKitchenForStudent)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	var resp []interface{}
	for _, v := range *identity {
		resp = append(resp, map[string]interface{}{
			"name":             v.UserIdentity.Name,
			"enterprise_name":  v.Enterprise.Name,
			"user_identity_id": v.UserIdentity.Id,
		})
	}
	e.OutSuc(c, map[string]interface{}{
		"list": resp,
	}, nil)
	return
}

func CentralKitchenForSchoolReserveDetail(c *gin.Context) {
	id := c.DefaultQuery("id", "")
	centralKitchenForSchoolPackageOrdForReserveDb := db.CentralKitchenForSchoolPackageOrdForReserve{}
	centralKitchenForSchoolPackageOrdForReserveDb.Set("")
	centralKitchenForSchoolPackageOrdForReserve, err := centralKitchenForSchoolPackageOrdForReserveDb.GetCentralKitchenForSchoolPackageOrdForReserveById(utils.StrToInt(id))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if centralKitchenForSchoolPackageOrdForReserve == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到相应记录")
		return
	}

	var m []*db.CentralKitchenForSchoolUserWithDayWithCentralKitchenForSchoolUserRefundDay
	err = db.Db.Where("central_kitchen_for_school_user_with_day.ord_no =?", centralKitchenForSchoolPackageOrdForReserve.OutTradeNo).
		Where("central_kitchen_for_school_user_with_day.date >=? and central_kitchen_for_school_user_with_day.date <=?", centralKitchenForSchoolPackageOrdForReserve.MealTimeStart, centralKitchenForSchoolPackageOrdForReserve.MealTimeEnd).
		And("central_kitchen_for_school_user_with_day.kind =?", centralKitchenForSchoolPackageOrdForReserve.Kind).
		Join("LEFT", "central_kitchen_for_school_user_refund_day", "central_kitchen_for_school_user_with_day.id = central_kitchen_for_school_user_refund_day.records_id").
		Find(&m)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	var resp []map[string]interface{}
	for _, v := range m {
		resp = append(resp, map[string]interface{}{
			"id":            v.CentralKitchenForSchoolUserWithDay.Id,
			"ord_no":        v.CentralKitchenForSchoolUserWithDay.OrdNo,
			"uid":           v.CentralKitchenForSchoolUserWithDay.Uid,
			"enterprise_id": v.CentralKitchenForSchoolUserWithDay.EnterpriseId,
			"identity_id":   v.CentralKitchenForSchoolUserWithDay.IdentityId,
			"kind":          v.CentralKitchenForSchoolUserWithDay.Kind,
			"amount":        v.CentralKitchenForSchoolUserWithDay.Amount,
			"date":          v.CentralKitchenForSchoolUserWithDay.Date,
			"state":         v.CentralKitchenForSchoolUserWithDay.State,
			"refund_date":   v.CentralKitchenForSchoolUserRefundDay.RefundDate,
		})
	}
	e.OutSuc(c, map[string]interface{}{
		"list": resp,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForBreakfast),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForLunch),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForLunch,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForDinner),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForDinner,
			},
		},
		"state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForWait),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForAlready),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForAlready,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForCanceling),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForCanceling,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForCancel),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForCancel,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolOrdRefund(c *gin.Context) {
	var req md.CentralKitchenForSchoolOrdRefundReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	err = svc2.CentralKitchenForSchoolOrdRefund(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolBatchAskForLeave(c *gin.Context) {
	Kind := c.DefaultQuery("kind", "1")
	switch Kind {
	case "1":
		//按学校
		var req md.CentralKitchenForSchoolBatchAskForLeaveReqBySchool
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		err = svc2.CentralKitchenForSchoolBatchAskForLeaveBySchool(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	case "2":
		//按年级
		var req md.CentralKitchenForSchoolBatchAskForLeaveReqByGrade
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		err = svc2.CentralKitchenForSchoolBatchAskForLeaveByGrade(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	case "3":
		//按班级
		var req md.CentralKitchenForSchoolBatchAskForLeaveReqByClass
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		err = svc2.CentralKitchenForSchoolBatchAskForLeaveByClass(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	}

	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolOrdDetail(c *gin.Context) {
	outTradeNo := c.DefaultQuery("out_trade_no", "")
	centralKitchenForSchoolPackageOrd := db.CentralKitchenForSchoolPackageOrd{}
	centralKitchenForSchoolPackageOrd.Set(outTradeNo)
	ord, err := centralKitchenForSchoolPackageOrd.GetCentralKitchenForSchoolPackageOrd()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if ord == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应订单记录")
		return
	}
	centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
	centralKitchenForSchoolUserWithDayDb.Set(0)
	list, err := centralKitchenForSchoolUserWithDayDb.FindCentralKitchenForSchoolUserWithDayByOrdNo(ord.OutTradeNo)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"list": list,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForBreakfast),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForLunch),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForLunch,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForDinner),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForDinner,
			},
		},
		"state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForWait),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForAlready),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForAlready,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForCanceling),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForCanceling,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForCancel),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForCancel,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolGradeList(c *gin.Context) {
	var req md.CentralKitchenForSchoolGradeListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolGradeList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func CentralKitchenForSchoolClassList(c *gin.Context) {
	var req md.CentralKitchenForSchoolClassListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolClassList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func CentralKitchenForSchoolGradeDelete(c *gin.Context) {
	gradeId := c.Param("id")
	//1、查找当前年级
	gradeDb := db.GradeDb{}
	gradeDb.Set(0)
	grade, err := gradeDb.GetGrade(utils.StrToInt(gradeId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//2、查找当前年级下是否还包含班级
	classDb := db.ClassDb{}
	classDb.Set(grade.Id)
	class, err := classDb.FindClass()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if len(*class) > 0 {
		e.OutErr(c, e.ERR, "当前年级下存在未删除的班级!")
		return
	}
	_, err = gradeDb.GradeDeleteBySession(grade.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolClassDelete(c *gin.Context) {
	classId := c.Param("id")
	//1、查找当前年级
	classDb := db.ClassDb{}
	classDb.Set(0)
	class, err := classDb.GetClass(utils.StrToInt(classId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	_, err = classDb.ClassDeleteBySession(class.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//2、删除当前班级下的所有关联学生
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	_, err = classWithUserDb.DeleteClassWithUserByClass(classId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}
